@@ -19,9 +19,6 @@
 #include <vector>
 // Column
 #include "Column.h"
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 
 #ifdef SSTREAM_DEFECT
 #include <strstream>
@@ -31,6 +28,8 @@
 
 #include <memory>
 #include <numeric>
+#include <algorithm>
+
 namespace CCfits {
 
         class Table;
@@ -260,13 +259,16 @@ namespace CCfits {
           if ( that.m_data.size() != n ) return false;
           for (size_t i = 0; i < n ; i++)
           {
-                size_t nn = m_data[i].size();
-                // first check size (also, == on 2 valarrays is only defined if they
-                // are equal in size).
-                if (that.m_data[i].size() != nn ) return false;
-
-                std::valarray<bool> test = (m_data[i] == that.m_data[i]);
-                for (size_t j = 0; j < nn ; j++ ) if ( !test[j] ) return false;
+                const std::valarray<T>& thisValArray=m_data[i];
+                const std::valarray<T>& thatValArray=that.m_data[i];
+                size_t nn = thisValArray.size();
+                if (thatValArray.size() != nn ) return false;
+     
+                for (size_t j = 0; j < nn ; j++ ) 
+                {
+                   if (thisValArray[j] != thatValArray[j])
+                      return false;
+                }
           }
           return true;
   }
